'''
Created by auto_sdk on 2022.09.20
'''
from seven_top.top.api.base import RestApi
class FuwuPurchaseOrderPayRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.appkey = None
		self.device_type = None
		self.order_id = None
		self.out_order_id = None

	def getapiname(self):
		return 'taobao.fuwu.purchase.order.pay'



'''
Created by auto_sdk on 2021.07.20
'''
from seven_top.top.api.base import RestApi
class AlibabaLafiteSellerBenefitListRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.benefit_read_top_query = None

	def getapiname(self):
		return 'alibaba.lafite.seller.benefit.list'



'''
Created by auto_sdk on 2021.06.15
'''
from seven_top.top.api.base import RestApi
class MiniappAppSellerConfigCompleteRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.app_id = None
		self.version = None

	def getapiname(self):
		return 'taobao.miniapp.app.seller.config.complete'



'''
Created by auto_sdk on 2018.07.25
'''
from seven_top.top.api.base import RestApi
class AlipayXiaodaiUserPermitRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.user_id = None

	def getapiname(self):
		return 'alipay.xiaodai.user.permit'



'''
Created by auto_sdk on 2021.01.13
'''
from seven_top.top.api.base import RestApi
class OpentradeGroupActivtiyQueryRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.group_activity_id = None
		self.item_id = None
		self.page_index = None
		self.page_size = None

	def getapiname(self):
		return 'taobao.opentrade.group.activtiy.query'



'''
Created by auto_sdk on 2024.05.22
'''
from seven_top.top.api.base import RestApi
class OpencrmComponentDataQueryRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.open_data_component_query = None

	def getapiname(self):
		return 'taobao.opencrm.component.data.query'



# -*- coding: utf-8 -*-
'''
Created by auto_sdk on 2021.09.14 奇门增量获取卖家订单
'''
from seven_top.top.api.base import RestApi
class QmTbCrmTradeIncrementRdsGet(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.trade_info = ""

	def getapiname(self):
		return 'taobao.trade.increment.rds.get'


'''
Created by auto_sdk on 2019.08.26
'''
from seven_top.top.api.base import RestApi
class AlibabaBeneiftDrawRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.app_name = None
		self.ename = None
		self.ip = None

	def getapiname(self):
		return 'alibaba.beneift.draw'



'''
Created by auto_sdk on 2022.04.21
'''
from seven_top.top.api.base import RestApi
class OpencrmOrderRecordAddRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.order_record_dto = None

	def getapiname(self):
		return 'taobao.opencrm.order.record.add'



'''
Created by auto_sdk on 2022.09.20
'''
from seven_top.top.api.base import RestApi
class FuwuSpConfirmApplyRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.param_income_confirm_d_t_o = None

	def getapiname(self):
		return 'taobao.fuwu.sp.confirm.apply'
